<?php

namespace App\Repositories;

use App\Entities\Ingredient;
use App\Entities\Pizza;use PDO;

class IngredientRepository extends Repository {

    public function getIngredientsForPizza($pizzaId) {
        $query = "SELECT id, name, quantity, unit FROM Ingredient WHERE idPizza = :pizzaId";
        $statement = $this->getPdo()->prepare($query);
        $statement->execute(['pizzaId' => $pizzaId]);

        $ingredients = [];
        while ($row = $statement->fetch(PDO::FETCH_ASSOC)) {
            $ingredients[] = new Ingredient($row['id'], $row['name'], $row['quantity'], $row['unit']);
        }

        return $ingredients;
    }

    public function createIngredient(Ingredient $ingredient, int $pizza): false|string
    {
        $query = "INSERT INTO Ingredient (name, quantity, unit, idPizza) VALUES (:name, :quantity, :unit, :idPizza)";
        $statement = $this->getPdo()->prepare($query);
        $statement->execute([
            'name' => $ingredient->name,
            'quantity' => $ingredient->quantity,
            'unit' => $ingredient->unit,
            'idPizza' => $pizza
        ]);

        // Retourner l'ID de l'ingrédient inséré
        return $this->getPdo()->lastInsertId();
    }

    public function updateIngredient(Ingredient $ingredient): bool
    {
        $query = "UPDATE Ingredient SET name = :name, quantity = :quantity, unit = :unit WHERE id = :id";
        $statement = $this->getPdo()->prepare($query);
        $statement->execute([
            'id' => $ingredient->id,
            'name' => $ingredient->name,
            'quantity' => $ingredient->quantity,
            'unit' => $ingredient->unit
        ]);

        // Vérifier si l'ingrédient a été mis à jour avec succès
        return $statement->rowCount() > 0;
    }
}

?>
